=== modified file 'drizzled/plugin/scheduler.cc'
--- drizzled/plugin/scheduler.cc	2010-05-15 18:23:34 +0000
+++ drizzled/plugin/scheduler.cc	2010-08-05 20:33:18 +0000
@@ -31,6 +31,8 @@
 namespace drizzled
 {
 
+extern size_t my_thread_stack_size;
+
 vector<plugin::Scheduler *> all_schedulers;
 
 /* Globals (TBK) */
@@ -107,4 +109,9 @@
   return scheduler;
 }
 
+size_t plugin::Scheduler::getThreadStackSize() const
+{
+  return my_thread_stack_size;
+}
+
 } /* namespace drizzled */

=== modified file 'drizzled/plugin/scheduler.h'
--- drizzled/plugin/scheduler.h	2010-02-04 08:14:46 +0000
+++ drizzled/plugin/scheduler.h	2010-08-05 20:33:18 +0000
@@ -71,6 +71,11 @@
   static bool setPlugin(const std::string& name);
   static Scheduler *getScheduler();
 
+  /**
+   * Return the thread stack size that should be used for all threads.
+   */
+  size_t getThreadStackSize() const;
+
 };
 
 } /* namespace plugin */

=== modified file 'plugin/multi_thread/multi_thread.cc'
--- plugin/multi_thread/multi_thread.cc	2010-07-18 06:07:19 +0000
+++ plugin/multi_thread/multi_thread.cc	2010-08-05 20:33:18 +0000
@@ -18,6 +18,7 @@
 #include "drizzled/pthread_globals.h"
 #include <boost/program_options.hpp>
 #include <drizzled/module/option_map.h>
+#include <drizzled/errmsg_print.h>
 
 namespace po= boost::program_options;
 using namespace std;
@@ -54,6 +55,16 @@
   if (thread_count >= max_threads)
     return true;
 
+  int err= pthread_attr_setstacksize(&attr, getThreadStackSize());
+
+  if (err != 0)
+  {
+    errmsg_printf(ERRMSG_LVL_ERROR,
+                  _("Unable to set thread stack size to %" PRId64 "\n"),
+                  static_cast<int64_t>(getThreadStackSize()));
+    return true;
+  }
+
   thread_count.increment();
 
   if (pthread_create(&session->real_id, &attr, session_thread,

=== added file 'tests/t/subselect_notembedded-master.opt'
--- tests/t/subselect_notembedded-master.opt	1970-01-01 00:00:00 +0000
+++ tests/t/subselect_notembedded-master.opt	2010-08-05 20:33:18 +0000
@@ -0,0 +1,1 @@
+--thread_stack=1048576

